@@ -6,7 +6,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @EXPORT);
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use Exporter::Lite;
 @EXPORT = qw(error _debug _set_error);
@@ -54,14 +54,7 @@ sub _set_error {
 
 Copyright 2004, Thomas R. Sibley.
 
-This work is licensed under the Creative Commons
-Attribution-NonCommercial-ShareAlike License revision 2.0.  To view a copy
-of this license, visit L<http://creativecommons.org/licenses/by-nc-sa/2.0/>
-or send a letter to:
-
-    Creative Commons
-    559 Nathan Abbott Way
-    Stanford, California 94305, USA.
+You may use, modify, and distribute this package under the same terms as Perl itself.
 
 =head1 AUTHOR
 
