@@ -6,10 +6,22 @@ use warnings;
 use strict;
 
 use vars '$VERSION';
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use Net::iTMS::Error;
 
+use overload
+	'""'     => sub { shift->as_string },
+	fallback => 1;
+
+sub as_string {
+    my $self = shift;
+    
+    return defined $self
+            ? $self->name
+            : undef;
+}
+
 =head1 NAME
 
 Net::iTMS::Song - Represents a song in the iTunes Music Store
@@ -96,6 +108,7 @@ sub album       { return $_[0]->{album} }
 sub genre       { return $_[0]->{genre} }
 sub year        { return $_[0]->{year} }
 sub number      { return $_[0]->{number} }
+sub track       { return $_[0]->{number} }
 sub count       { return $_[0]->{count} }
 sub disc_number { return $_[0]->{disc_number} }
 sub disc_count  { return $_[0]->{disc_count} }
@@ -112,14 +125,7 @@ sub price       { return $_[0]->{price} }
 
 Copyright 2004, Thomas R. Sibley.
 
-This work is licensed under the Creative Commons
-Attribution-NonCommercial-ShareAlike License revision 2.0.  To view a copy
-of this license, visit L<http://creativecommons.org/licenses/by-nc-sa/2.0/>
-or send a letter to:
-
-    Creative Commons
-    559 Nathan Abbott Way
-    Stanford, California 94305, USA.
+You may use, modify, and distribute this package under the same terms as Perl itself.
 
 =head1 AUTHOR
 
